@@ -1,6 +1,6 @@
 # fields  is a package for analysis of spatial data written for
 # the R software environment .
-# Copyright (C) 2016
+# Copyright (C) 2018
 # University Corporation for Atmospheric Research (UCAR)
 # Contact: Douglas Nychka, nychka@ucar.edu,
 # National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
@@ -55,6 +55,11 @@
   if (Distance == "rdist.earth" & !is.null(V)) {
     stop("V not supported with great circle distance")
   }
+  # use V the anisotropic scaling and rotation from covariance arguments 
+  # if exists
+  if( !is.null(cov.args$V) ){
+    V<- cov.args$V
+  }
   if (!is.null(V)) {
     if (theta != 1) {
       stop("can't specify both theta and V!")
@@ -73,7 +78,7 @@
     #
     if(is.na(distMat[1])) {
       # distMat not supplied so must compute it along with covariance matrix
-      # note overall scalling by theta (which is just theta under isotropic case)
+      # note overall scaling by theta (which is just theta under isotropic case)
       if(is.null(x2))
         distMat <- do.call(Distance, c(list(x1), Dist.args))
       else
