@@ -1,9 +1,22 @@
-# fields, Tools for spatial data
-# Copyright 2004-2011, Institute for Mathematics Applied Geosciences
-# University Corporation for Atmospheric Research
-# Licensed under the GPL -- www.gpl.org/licenses/gpl.html
+ # fields is a package for analysis of spatial data written for
+  # the R software environment .
+  # Copyright (C) 2018
+  # University Corporation for Atmospheric Research (UCAR)
+  # Contact: Douglas Nychka, nychka@ucar.edu,
+  # National Center for Atmospheric Research,
+  # PO Box 3000, Boulder, CO 80307-3000
+  #
+  # This program is free software; you can redistribute it and/or modify
+  # it under the terms of the GNU General Public License as published by
+  # the Free Software Foundation; either version 2 of the License, or
+  # (at your option) any later version.
+  # This program is distributed in the hope that it will be useful,
+  # but WITHOUT ANY WARRANTY; without even the implied warranty of
+  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  # GNU General Public License for more details.
 
-library( fields)
+
+suppressMessages(library(fields))
 # tests of predict.se
 # using approximations for conditional simulation on a grid. 
 #
@@ -13,7 +26,7 @@ test.for.zero.flag<-1
 long.test.flag<- FALSE
 
 data( ozone2)
-as.image(ozone2$y[16,], x= ozone2$lon.lat, ncol=24, nrow=20, 
+as.image(ozone2$y[16,], x= ozone2$lon.lat, ny=24, nx=20, 
           na.rm=TRUE)-> dtemp
 #
 # A useful discretized version of ozone2 data
